@@ -74,7 +74,7 @@ Here is an example:
     MatrixBuilder.add_matrix_indices(a_f, a_t, mapping)
     # => a_t is now [5, 6, 7, 8]
 
-This is a relatively computationally expensive method, and therefore a Cython version of ``indexer`` is used if present.
+This is a relatively computationally expensive method, and therefore a stand-alone library - `bw2speedups <https://pypi.python.org/pypi/bw2speedups>`_ - is used if installed. Install it with ``pip install bw2speedups``.
 
 Args:
     * *array_from* (array): 1-dimensional integer numpy array.
@@ -185,13 +185,17 @@ class TechnosphereBiosphereMatrixBuilder(MatrixBuilder):
             dirpath,
             [Database(name).filename for name in names]
         )
-        tech_array = array[
+        # take ~10 times faster than fancy indexing
+        # http://wesmckinney.com/blog/?p=215
+        tech_array = array.take(
             np.hstack((
                 np.where(array['type'] == TYPE_DICTIONARY["technosphere"])[0],
                 np.where(array['type'] == TYPE_DICTIONARY["production"])[0]
             ))
-        ]
-        bio_array = array[np.where(array['type'] == TYPE_DICTIONARY["biosphere"])]
+        )
+        bio_array = array.take(np.where(
+            array['type'] == TYPE_DICTIONARY["biosphere"]
+        )[0])
         tech_dict = cls.build_dictionary(np.hstack((
             tech_array['input'],
             tech_array['output'],
